function [phi,phider1,phider2] = basecheb(x,n,a,b);

% BASECHEB: [phi,phider1,phider2] = basecheb(x,n,a,b);
%
% Unidimensional Chebycheb polynomial basis
%
% Given m by 1 vector x, returns m by n arrays phi,
% phider1, and phider2, containing values, first
% derivatives, and second derivatives of order n
% Chebychev basis polynomials on [a,b] evaluated at x.
% Uses Clenshaw's recursion to compute values.

m = length(x);
%if (x<a) | (x>b), disp('extrapolating Chebychev basis'); end

phi = ones(m,1);
if n>1
   z = -1 + 2*(x-a)/(b-a);
   phi = [ phi z ];
   for j=3:n
      phi = [phi 2*z.*phi(:,j-1)-phi(:,j-2)];
   end
end


if nargout<2, return; end
dop = chebdop(n,a,b);
phider1 = phi*dop;

if nargout<3, return; end
phider2 = phider1*dop;


function dop = chebdop(n,a,b);
j = 1:n; j = j(ones(n,1),:); i = j';
k = find(rem(i+j,2)==1 & j>i);
dop = zeros(n,n);
dop(k) = 4*(j(k)-1)/(b-a);
dop(1,:) = dop(1,:)/2;
dop = sparse(dop);
