function [phi,phider1,phider2] = basecspl(x,n,a,b);

% BASECSPL: [phi,phider1,phider2] = basecspl(x,n,a,b);
%
% Unidimensional cubic spline basis
%
% Given m by 1 vector x, returns m by n arrays phi,
% phider1, and phider2, containing values, first
% derivatives, and second derivatives of order n
% cubic spline basis functions on [a,b] evaluated at x.
% Imposes the not-a-knot condition.

if (x<a) | (x>b), disp('extrapolating cubic spline basis'); end

phi = basencub(x,n,a,b,0);

if nargout<2, return; end

phider1 = basencub(x,n,a,b,1);

if nargout<3, return; end

phider2 = basencub(x,n,a,b,2);


function phi = basencub(x,n,a,b,order);

m = length(x);
p = 4-order;
nint = n-1;
dx = (b-a)/nint;
z = (x-a)/dx;
i = fix(z)+1;
i = i.*(i>0 & i<= nint) + (i<1) + nint*(i>nint);
z = z-i+(p+1);
phi = zeros(m,p+1);
phi(:,p) = ones(m,1);
z = z(:,ones(p,1));
(1:p+1); k = ans(ones(m,1),:);
for j = 2:p;
   ii = (p+1-j):p;
   phi(:,ii) = (z(:,1:j)-k(:,ii)).*phi(:,ii)+(k(:,ii)+j-z(:,1:j)).*phi(:,ii+1);
end;
phi = phi(:,1:p)/prod(1:(p-1));
(1:m)'; r = ans(:,ones(p,1));
0:p-1; c = i(:,ones(p,1)) + ans(ones(m,1),:);
phi = sparse(r(:),c(:),phi(:),m,nint+p-1);

% Compute derivative operator
if order>0;
   op = 1/dx^order;
   for i = 1:order
      op = [0 op]-[op 0];
   end;
   ntmp = nint+3-order;
   op = spdiags(op(ones(ntmp,1),:),0:order,ntmp,ntmp+order);
   phi = phi*op;
end

% Natural spline conditions
%phi(:,2)   = phi(:,2)   + 2*phi(:,1);
%phi(:,3)   = phi(:,3)   -   phi(:,1);
%phi(:,n)   = phi(:,n)   -   phi(:,n+2);
%phi(:,n+1) = phi(:,n+1) + 2*phi(:,n+2);

% Not-a-knot conditions
phi(:,2)   = phi(:,2)   + 4*phi(:,1);
phi(:,3)   = phi(:,3)   - 6*phi(:,1);
phi(:,4)   = phi(:,4)   + 4*phi(:,1);
phi(:,5)   = phi(:,5)   - 1*phi(:,1);
phi(:,n-2) = phi(:,n-2) - 1*phi(:,n+2);
phi(:,n-1) = phi(:,n-1) + 4*phi(:,n+2);
phi(:,n)   = phi(:,n)   - 6*phi(:,n+2);
phi(:,n+1) = phi(:,n+1) + 4*phi(:,n+2);
phi(:,n+2)=[]; phi(:,1)=[];
