function [phi,phider1,phider2] = baselspl(x,n,a,b);

% BASELSPL: [phi,phider1,phider2] = baselspl(x,n,a,b);
%
% Unidimensional linear spline basis
%
% Given m by 1 vector x, returns m by n arrays phi,
% phider1, and phider2, containing values, first
% derivatives, and second derivatives of the order n
% linear spline basis functions on [a,b] evaluated at x.

m = length(x);
if (x<a) | (x>b), disp('extrapolating linear spline basis'); end

xwid = (b-a)/(n-1);
j = floor((x-a)/xwid) + 1;
j = min(j,n-1); j = max(j,1);
theta = (x-a)/xwid - (j-1);

phi = zeros(m,n);
for i=1:m
   phi(i,j(i)+1) =     theta(i);
   phi(i,j(i))   = 1 - theta(i);
end

if nargout<2, return; end

phider1 = zeros(m,n);
for i=1:m
   phider1(i,j(i)+1) =  1/xwid;
   phider1(i,j(i))   = -1/xwid;
end

if nargout<3, return; end

phider2 = zeros(m,n);
