function [x,f,it,normf] = bisect(a,b,func,maxit,tol);

% BISECT: [x,f,it,normf] = bisect(a,b,func,maxit,tol);
%
% Bisection rootfinding method
%
% Computes root of univariate nonlinear function.
% On input, a and b bracket the root, func is function
% f = func(x) that returns function value, maxit if
% maximum number of iterations, and tol is convergence
% tolerance. Returns root x, function value f, number
% of iterations it, and norm of f normf.

sa = sign(feval(func,a));
sb = sign(feval(func,b));
if sa*sb >= 0, error ('same sign at a and b'), end;
for it=1:maxit
   x = (a+b)/2;
   f = feval(func,x);
   normf = norm(f);
   if normf<tol, return, end;
   sx = sign(f);
   if sx == sa
      a = x;
      sa = sx;
   else
      b = x;
      sb = sx;
   end
end
