function jac = findiff(f,x);

% FINDIFF: jac = findiff(f,x);
%
% Compute finite difference Jacobian
%
% Given an function f:R^d-->R^n, and a d-vector x,
% findiff computes the finite difference Jacobian
% of f at x, an n by d matrix. In the call to the
% function, f is the string giving the name of the
% function that returns the value of f at x.

d = length(x);
jac = [];
for j=1:d
   delta = zeros(d,1);
   delta(j) = x(j)+max(1.e-8*abs(x(j)),1.e-10)-x(j);
   fplus = feval(f,x+delta);
   fmins = feval(f,x-delta); 
   jac = [jac (fplus-fmins)/(2*delta(j)) ];
end
