function y = kronmult(A,x)

% KRONMULT: y = kronmult(A,x)
%
% Kronecker product of matrices times a vector
%
% Given d by 1 cell array A whose kth element A{k} is
% an m(k) by n(k) matrix, and an prod(n) by mx vector x,
% forms the prod(m) by mx vector
%    y  = [A{1} X A{2} X ... X A{d}] * x
% where X is Kronecker product operator.

x = x(:);
d = length(A);
m = zeros(d,1);
n = zeros(d,1);
for i=1:d
   [m(i),n(i)] = size(A{i});
end
p = 1; q = length(x); y = x;
for i=d:-1:1
   q = q/n(i);
   y = reshape(y,p,n(i),q);
   for j=1:q
      y(:,:,j) = y(:,:,j)*A{i}';
   end
   p = p*m(i);
end   
y = y(:); y = reshape(y,p,length(y)/p);
