function y = kronrow(A,x);

% KRONROW: y = kronrow(A,x)
%
% Rowwise Kronecker product of matrices times a matrix
%
% Given d by 1 cell array A whose kth element A{k} is
% an m by n(k) matrix, and an prod(n) by p vector x,
% forms the m by p vector y whose i-jth entry is
%    y(i,j)  = [A{1}(i,:) X A{2}(i,:) X ... X A{d}(i,:)] * x(:,j)
% where X is kronecker product operator.  Function used
% to evaluate p linear combinations of d-dimensional basis
% functions at m points (see evalbase.m).

d = length(A);
for i=1:d;
  [m,n(i)] = size(A{i});
end;

B = ones(m,1);
for i=d-1:-1:1
   q = size(B,2);
   j1 = 1:n(i); j1 = j1(ones(q,1),:);
   j2 = (1:q)'; j2 = j2(:,ones(1,n(i)));
   B = A{i}(:,j1).*B(:,j2);
end   

p = size(x,2);
y = zeros(m,p);
for k=1:p
   y(:,k) = sum(B.*(A{d}*reshape(x(:,k),n(d),prod(n(1:d-1)))),2);
   % same as y = dot(B,y,2), only faster
end
