function x = kronsolv(A,b)

% KRONSOLV: x = kronsolv(A,b)
%
% Solve linear equation involving Kronecker product of matrices
%
% Given d by 1 cell array A whose kth element A{k} is
% an m(k) by n(k) matrix, and an prod(m) by 1 vector b,
% solves the linear equation
%    [A{1} X A{2} X ... X A{d}] * x = b
% for the prod(n) by 1 vector x, where X is Kronecker
% product operator.

d = length(A);
m = zeros(d,1);
n = zeros(d,1);
for i=1:d
   [m(i),n(i)] = size(A{i});
end
p = 1; q = prod(n); x = b;
for i=d:-1:1
   q = q/n(i);
   x = reshape(x,p,n(i),q);
   for j=1:q
      x(:,:,j) = x(:,:,j)/A{i}';
   end
   p = p*m(i);
end   
x = x(:);
