function [x,z,it] = lcpsolve(x,a,b,M,q)

% LCPSOLVE: [x,z,it] = lcpsolve(x,a,b,M,q)
%
% Solves general linear complimentarity problem
%
% Takes as input an n by n matrix M and n by 1 vectors q,
% a, and b, and solves the general linear complimentarity
% problem
%
%  z = M x + q;
%  a <= x <= b;
%  x_i>a_i --> z_i>=0;
%  x_i<b_i --> z_i<=0;
%
% for the n by 1 solution vector x.  Uses the block Bard
% method, taking as input an initial guess for x. Returns
% it=-1 if no solution found.

eps = 1e-10;
n = length(x);
nbase = 3^n;
visit = zeros(nbase,1);
powr3 = 3.^[n-1:-1:0];
basis = [];
for it=1:nbase
   w = x+M*x+q;
   i = find(w<=a);
   j = find(a<w & w<b);
   k = find(w>=b);
   l = 2*sum(powr3(k))+sum(powr3(j))+1;
   if visit(l)==1
      if isempty(basis), basis = cartgrid([-1;0;1],n); end
      l = min(find(visit==0));
      t = basis(l,:)';
      i = find(t==-1);
      j = find(t== 0);
      k = find(t== 1);
   end
   visit(l)=1;
   if isempty(i)&isempty(k)
      x = -M\q;
   else
      x(i) = a(i);
      x(k) = b(k);
      if ~isempty(j)
         x(j) = -M(j,j)\(q(j)+M(j,[i;k])*x([i;k]));
      end
   end
   z = M*x+q;
   if all(z(i)-eps<0)&all(z(k)+eps>0)&all(a<x+eps)&all(x<b+eps), return, end;
end
it = -1;
