function [x,f,it,normf] = newtfd(xinit,func,maxit,maxcut,tol)

% NEWTFD: [x,f,it,normf] = newtfd(xinit,func,maxit,maxcut,tol)
%
% Newton's rootfinding method, finite difference derivatives
%
% Computes root of n-vector-valued nonlinear function of
% n-vector x.  On input, xinit is initial guess for root,
% func is function f = func(x) that returns function value
% f, maxit is maximum number of iterations, maxcut is maximum
% number of step halvings, and tol is convergence tolerance.
% Returns root x, function value f, number of iterations it,
% and norm of f normf. Use maxcut=0 unless convergence problems
% arise.

maxpass = max(1,maxcut+1);
x = xinit;
f = feval(func,x);
d = findiff(func,x);
normf = norm(f);
for it=1:maxit
   normfold = normf;
   delx = -d\f;
   x = x + delx;
   for ic=1:maxpass
      f = feval(func,x);
      d = findiff(func,x);
      normf = norm(f);
      if normf > normfold & ic<maxpass
         delx = delx/2;
         x = x - delx;
      else
         break
      end;
   end
   %fprintf('\n%5i %10.2e',it,normf);
   if normf<tol, return, end;
end
