function [x,xcoord] = nodecheb(n,a,b)

% NODECHEB: [x,xcoord] = nodecheb(n,a,b)
%
% Computes Chebycheb nodes for intervals in R^n
%
% If dimension d of n, a, and b is one, returns n by
% by 1 vector x containing the n Chebychev nodes for
% the interval [a,b]. If dimension d>1, returns d by 1
% cell array xcoord whose kth entry is the n(k) by 1
% vector of the n(k) Chebychev nodes for the interval
% [a(k),b(k)]; also returns prod(n) by d vector x of
% grid points created by forming Cartesian product of
% vectors in xcoord.

d = length(n);
m = (a+b)/2; h = (b-a)/2;
if d==1
   x = m-h*cos(((1:n)-0.5)*pi/n)';
else
   for k=1:d
      xcoord{k} = m(k)-h(k)*cos(((1:n(k))-0.5)*pi/n(k))';
   end   
   x = cartgrid(xcoord);
end
