function P = projcheb(n);

% PROJCHEB: P = projcheb(n);
%
% Compute Chebycheb projection matrix
%
% If length d of n equals one, returns the order n Chebychev
% projection matrix P. If dimension d>1, returns d by 1 cell
% array P whose kth entry P{k} is the order n(k) Chebychev
% projection matrix; the Kronecker product of these matrices
% is the d-dimensional Chebychev projection matrix.

d = length(n);
if d==1
   j = (1:n); i=j';
   P = 2*cos((i-1)*(n-j+0.5)*pi/n)/n;
   P(1,:) = P(1,:)/2;
else
   for k=1:d
      j = (1:n(k)); i=j';
      P{k} = 2*cos((i-1)*(n(k)-j+0.5)*pi/n(k))/n(k);
      P{k}(1,:) = P{k}(1,:)/2;
   end
end
