function P = projcspl(n,a,b);

% PROJCSPL: P = projcspl(n,a,b);
%
% Compute cubic spline projection matrix
%
% If dimension d of n, a, and b is one, returns the order n
% cubic spline projection matrix P for the interval [a,b].
% If dimension d>1, returns d by 1 cell array P whose kth
% entry P{k} is the order n(k) cubic spline projection matrix
% for [a(k),b(k)]; the Kronecker product of these matrices
% is the d-dimensional cubic spline projection matrix for
% the hyperinterval [a,b].

d = length(n);
if d==1
   x = nodeunif(n,a,b);
   phi = basecspl(x,n,a,b);
   P = inv(phi);
else
   [x,xcoord] = nodeunif(n,a,b);
   for k=1:d
      phi = basecspl(xcoord{k},n(k),a(k),b(k));
      P{k} = inv(phi);
   end
end
